summaryrefslogtreecommitdiffstats
path: root/tdeio/tdeio/kshellcompletion.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdeio/tdeio/kshellcompletion.cpp')
-rw-r--r--tdeio/tdeio/kshellcompletion.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdeio/tdeio/kshellcompletion.cpp b/tdeio/tdeio/kshellcompletion.cpp
index 2fb67a31f..789a5ce05 100644
--- a/tdeio/tdeio/kshellcompletion.cpp
+++ b/tdeio/tdeio/kshellcompletion.cpp
@@ -77,7 +77,7 @@ TQString KShellCompletion::makeCompletion(const TQString &text)
/*
* postProcessMatch, postProcessMatches
*
* Called by KCompletion before emitting match() and matches()
*
* Add add the part of the text that was not completed
* Add quotes when needed
@@ -121,11 +121,11 @@ void KShellCompletion::postProcessMatches( TQStringList *matches ) const
}
}
-void KShellCompletion::postProcessMatches( KCompletionMatches *matches ) const
+void KShellCompletion::postProcessMatches( TDECompletionMatches *matches ) const
{
KURLCompletion::postProcessMatches( matches );
- for ( KCompletionMatches::Iterator it = matches->begin();
+ for ( TDECompletionMatches::Iterator it = matches->begin();
it != matches->end(); it++ )
{
if ( !(*it).value().isNull() ) {
@@ -77,7 +77,7 @@ TQString KShellCompletion::makeCompletion(const TQString &text)
* postProcessMatch, postProcessMatches
*
- * Called by KCompletion before emitting match() and matches()
+ * Called by TDECompletion before emitting match() and matches()
*
* Add add the part of the text that was not completed